@@ -5,7 +5,7 @@ use super::InputFormatToken;
 use nom::{error, IResult, branch::alt, bytes::complete::{tag, take_until}, character::complete::{alphanumeric0, char}, multi::many0, sequence::delimited};
 
 impl<'a> InputFormatToken<'a> {
-    fn from_str(text: &'a str) -> Self {
+    fn type_from_str(text: &'a str) -> Self {
         match text {
             "i32" => Self::Type(TypeId::of::<i32>()),
             "u32" => Self::Type(TypeId::of::<u32>()),
@@ -14,7 +14,8 @@ impl<'a> InputFormatToken<'a> {
             "u64" => Self::Type(TypeId::of::<u64>()),
             "f64" => Self::Type(TypeId::of::<f64>()),
             "string" => Self::Type(TypeId::of::<String>()),
-            text => Self::Text(text),
+            "" => Self::GenericType,
+            text => Self::Text(text), // TODO: Refactor this to return result and handle it.
         }
     }
 }
@@ -45,7 +46,7 @@ fn text(input: &str) -> IResult<&str, InputFormatToken> {
 
 fn type_format(input: &str) -> IResult<&str, InputFormatToken> {
     let (remaining, type_name) = delimited(char('{'), alphanumeric0, char('}'))(input)?;
-    match InputFormatToken::from_str(type_name) {
+    match InputFormatToken::type_from_str(type_name) {
         InputFormatToken::Text(_) => Err(nom::Err::Failure(error::Error { input, code: error::ErrorKind::AlphaNumeric })),
         type_format => Ok((remaining, type_format)),
     }
